package com.sun.java.swing.plaf.windows;

import javax.swing.JLabel;
import java.awt.Container;
import java.awt.Window;
import java.awt.Component;
import java.awt.Point;
import javax.swing.plaf.UIResource;
import java.awt.Color;
import javax.swing.ButtonModel;
import javax.swing.JMenu;
import javax.swing.UIManager;
import java.awt.FontMetrics;
import javax.swing.JMenuItem;
import sun.swing.SwingUtilities2;
import java.awt.Rectangle;
import javax.swing.AbstractButton;
import java.awt.Graphics;

public class WindowsGraphicsUtils
{
    public WindowsGraphicsUtils() {
    }
    
    public static void paintText(Graphics g, AbstractButton c, Rectangle rectangle, String s, int n) {
        FontMetrics fontMetrics = SwingUtilities2.getFontMetrics(c, g);
        int displayedMnemonicIndex = c.getDisplayedMnemonicIndex();
        if (WindowsLookAndFeel.isMnemonicHidden()) {
            displayedMnemonicIndex = -1;
        }
        if (XPStyle.getXP() != null && !(c instanceof JMenuItem)) {
            paintXPText(c, g, rectangle.x + n, rectangle.y + fontMetrics.getAscent() + n, s, displayedMnemonicIndex);
        }
        else {
            paintClassicText(c, g, rectangle.x + n, rectangle.y + fontMetrics.getAscent() + n, s, displayedMnemonicIndex);
        }
    }
    
    static void paintClassicText(AbstractButton c, Graphics g, int n, int n2, String text, int underlinedIndex) {
        ButtonModel model = c.getModel();
        c.getForeground();
        if (model.isEnabled()) {
            if ((!(c instanceof JMenuItem) || !model.isArmed()) && (!(c instanceof JMenu) || (!model.isSelected() && !model.isRollover()))) {
                g.setColor(c.getForeground());
            }
            SwingUtilities2.drawStringUnderlineCharAt(c, g, text, underlinedIndex, n, n2);
        }
        else {
            Color color = UIManager.getColor("Button.shadow");
            Color color2 = UIManager.getColor("Button.disabledShadow");
            if (model.isArmed()) {
                color = UIManager.getColor("Button.disabledForeground");
            }
            else {
                if (color2 == null) {
                    color2 = c.getBackground().darker();
                }
                g.setColor(color2);
                SwingUtilities2.drawStringUnderlineCharAt(c, g, text, underlinedIndex, n + 1, n2 + 1);
            }
            if (color == null) {
                color = c.getBackground().brighter();
            }
            g.setColor(color);
            SwingUtilities2.drawStringUnderlineCharAt(c, g, text, underlinedIndex, n, n2);
        }
    }
    
    static void paintXPText(AbstractButton abstractButton, Graphics graphics, int n, int n2, String s, int n3) {
        paintXPText(abstractButton, WindowsButtonUI.getXPButtonType(abstractButton), WindowsButtonUI.getXPButtonState(abstractButton), graphics, n, n2, s, n3);
    }
    
    static void paintXPText(AbstractButton abstractButton, TMSchema.Part part, TMSchema.State state, Graphics graphics, int x, int y, String s, int n) {
        XPStyle xp = XPStyle.getXP();
        if (xp == null) {
            return;
        }
        Color color = abstractButton.getForeground();
        if ((color instanceof UIResource)) {
            color = xp.getColor(abstractButton, part, state, TMSchema.Prop.TEXTCOLOR, abstractButton.getForeground());
            if (part == TMSchema.Part.TP_BUTTON && state == TMSchema.State.DISABLED && color.equals(xp.getColor(abstractButton, part, TMSchema.State.NORMAL, TMSchema.Prop.TEXTCOLOR, abstractButton.getForeground()))) {
                color = xp.getColor(abstractButton, TMSchema.Part.BP_PUSHBUTTON, state, TMSchema.Prop.TEXTCOLOR, color);
            }
            TMSchema.TypeEnum typeEnum = xp.getTypeEnum(abstractButton, part, state, TMSchema.Prop.TEXTSHADOWTYPE);
            if (typeEnum == TMSchema.TypeEnum.TST_SINGLE || typeEnum == TMSchema.TypeEnum.TST_CONTINUOUS) {
                Color color2 = xp.getColor(abstractButton, part, state, TMSchema.Prop.TEXTSHADOWCOLOR, Color.black);
                Point point = xp.getPoint(abstractButton, part, state, TMSchema.Prop.TEXTSHADOWOFFSET);
                if (point != null) {
                    graphics.setColor(color2);
                    SwingUtilities2.drawStringUnderlineCharAt(abstractButton, graphics, s, n, x + point.x, y + point.y);
                }
            }
        }
        graphics.setColor(color);
        SwingUtilities2.drawStringUnderlineCharAt(abstractButton, graphics, s, n, x, y);
        return;
    }
    
    static boolean isLeftToRight(Component component) {
        return component.getComponentOrientation().isLeftToRight();
    }
    
    static void repaintMnemonicsInWindow(Window window) {
        if (window == null || !window.isShowing()) {
            return;
        }
        Window[] ownedWindows = window.getOwnedWindows();
        for (int i = 0; i < ownedWindows.length; ++i) {
            repaintMnemonicsInWindow(ownedWindows[i]);
        }
        repaintMnemonicsInContainer(window);
        return;
    }
    
    static void repaintMnemonicsInContainer(Container container) {
        for (int i = 0; i < container.getComponentCount(); ++i) {
            Component component = container.getComponent(i);
            if (component != null && component.isVisible()) {
                if (component instanceof AbstractButton && ((AbstractButton)component).getMnemonic() != 0) {
                    component.repaint();
                }
                else if (component instanceof JLabel && ((JLabel)component).getDisplayedMnemonic() != 0) {
                    component.repaint();
                }
                else if ((component instanceof Container)) {
                    repaintMnemonicsInContainer((Container)component);
                }
            }
        }
    }
}
